@@ -17,6 +17,7 @@
 static int et64_open(ifd_reader_t * reader, const char *device_name)
 {
 	ifd_device_t *dev;
+	ifd_device_params_t params;
 
 	reader->name = "Aladdin eToken PRO 64k";
 	reader->nslots = 1;
@@ -29,6 +30,14 @@ static int et64_open(ifd_reader_t * reader, const char *device_name)
 		return -1;
 	}
 
+        params = dev->settings;
+        params.usb.interface = 0;
+        if (ifd_device_set_parameters(dev, &params) < 0) {
+                ct_error("etoken64: setting parameters failed", device_name);
+                ifd_device_close(dev);
+                return -1;
+        }
+
 	reader->device = dev;
 
 	return 0;
