@@ -15,6 +15,7 @@
 static int ikey2k_open(ifd_reader_t * reader, const char *device_name)
 {
 	ifd_device_t *dev;
+        ifd_device_params_t params;
 
 	reader->name = "Rainbow iKey 2032";
 	reader->nslots = 1;
@@ -26,6 +27,14 @@ static int ikey2k_open(ifd_reader_t * reader, const char *device_name)
 		return -1;
 	}
 
+        params = dev->settings;
+        params.usb.interface = 0;
+        if (ifd_device_set_parameters(dev, &params) < 0) {
+                ct_error("ikey2k: setting parameters failed", device_name);
+                ifd_device_close(dev);
+                return -1;
+        }
+
 	reader->device = dev;
 
 	return 0;
