@@ -19,8 +19,8 @@ int ifd_init(void)
 
 	/* initialize ltdl */
 	i = lt_dlinit();
-	if (i != 0) 
-		ct_error("lt_dlinit returned %d",i);
+	if (i != 0)
+		ct_error("lt_dlinit returned %d", i);
 
 	/* Register built-in drivers */
 	ifd_acr30u_register();
@@ -35,8 +35,12 @@ int ifd_init(void)
 	ifd_ikey3k_register();
 	ifd_kaan_register();
 	ifd_pertosmart_ac1030_register();
+	ifd_pertosmart_ac1038_register();
 	ifd_smartboard_register();
+	ifd_smph_register();
+	ifd_starkey_register();
 	ifd_towitoko_register();
+	ifd_wbeiuu_register();
 	/* ccid last */
 	ifd_ccid_register();
 
@@ -67,8 +71,10 @@ int ifd_init(void)
 		}
 		n = ifd_conf_get_nodes("driver", nodes, n);
 		for (i = 0; i < n; i++) {
-			if (configure_driver(nodes[i]))
+			if (configure_driver(nodes[i])) {
+				free(nodes);
 				return 1;
+			}
 		}
 		free(nodes);
 	}
