@@ -231,7 +231,7 @@ int do_lock(ct_socket_t * sock, ifd_reader_t * reader, int unit,
 	if (unit > reader->nslots)
 		return IFD_ERROR_INVALID_SLOT;
 
-	if (ct_tlv_get_int(args, CT_TAG_LOCKTYPE, &lock_type) < 0)
+	if (ct_tlv_get_int(args, CT_TAG_LOCKTYPE, &lock_type) == 0)
 		return IFD_ERROR_MISSING_ARG;
 
 	if ((rc = ifdhandler_lock(sock, unit, lock_type, &lock)) < 0)
@@ -251,7 +251,7 @@ int do_unlock(ct_socket_t * sock, ifd_reader_t * reader, int unit,
 	if (unit > reader->nslots)
 		return IFD_ERROR_INVALID_SLOT;
 
-	if (ct_tlv_get_int(args, CT_TAG_LOCK, &lock) < 0)
+	if (ct_tlv_get_int(args, CT_TAG_LOCK, &lock) == 0)
 		return IFD_ERROR_MISSING_ARG;
 
 	if ((rc = ifdhandler_unlock(sock, unit, lock)) < 0)
@@ -406,7 +406,8 @@ int do_set_protocol(ifd_reader_t * reader, int unit, ct_tlv_parser_t * args,
 	if (unit > reader->nslots)
 		return IFD_ERROR_INVALID_SLOT;
 
-	ct_tlv_get_int(args, CT_TAG_PROTOCOL, &protocol);
+	if (ct_tlv_get_int(args, CT_TAG_PROTOCOL, &protocol) == 0)
+		return IFD_ERROR_MISSING_ARG;
 
 	rc = ifd_set_protocol(reader, unit, protocol);
 	if (rc < 0)
@@ -429,7 +430,7 @@ int do_memory_write(ifd_reader_t * reader, int unit, ct_tlv_parser_t * args,
 	if (unit > reader->nslots)
 		return IFD_ERROR_INVALID_SLOT;
 
-	if (!ct_tlv_get_int(args, CT_TAG_ADDRESS, &address)
+	if (ct_tlv_get_int(args, CT_TAG_ADDRESS, &address) == 0
 	    || !ct_tlv_get_opaque(args, CT_TAG_DATA, &data, &data_len))
 		return IFD_ERROR_MISSING_ARG;
 
@@ -451,7 +452,7 @@ int do_memory_read(ifd_reader_t * reader, int unit, ct_tlv_parser_t * args,
 	if (unit > reader->nslots)
 		return IFD_ERROR_INVALID_SLOT;
 
-	if (!ct_tlv_get_int(args, CT_TAG_ADDRESS, &address)
+	if (ct_tlv_get_int(args, CT_TAG_ADDRESS, &address) == 0
 	    || !ct_tlv_get_int(args, CT_TAG_COUNT, (unsigned int *)&data_len))
 		return IFD_ERROR_MISSING_ARG;
 
