@@ -21,40 +21,10 @@ ifd_reader_t *ifd_open(const char *driver_name, const char *device_name)
 	ifd_reader_t *reader;
 
 	ifd_debug(1, "trying to open %s@%s", driver_name, device_name);
-	if (!driver_name || !strcmp(driver_name, "auto")) {
-		char pnp_id[64];
-
-		if (ifd_device_identify(device_name, pnp_id, sizeof(pnp_id)) <
-		    0) {
-			ct_error("%s: unable to identify device, "
-				 "please specify driver", device_name);
-			return NULL;
-		}
-#if 1
-		/* Currently not supported */
-		ct_error("%s: plug and play not supported", device_name);
+	driver = ifd_driver_get(driver_name);
+	if (driver == NULL) {
+		ct_error("%s: driver not available", driver_name);
 		return NULL;
-#else
-		if (!(driver_name = ifd_driver_for_id(pnp_id))) {
-			ct_error("%s: no driver for ID %s, "
-				 "please specify driver", device_name, pnp_id);
-			return NULL;
-		}
-
-		driver = ifd_driver_get(driver_name);
-		if (driver == NULL) {
-			ct_error("%s: driver \"%s\" not available "
-				 "(identified as %s)",
-				 device_name, driver_name, pnp_id);
-			return NULL;
-		}
-#endif
-	} else {
-		driver = ifd_driver_get(driver_name);
-		if (driver == NULL) {
-			ct_error("%s: driver not available", driver_name);
-			return NULL;
-		}
 	}
 
 	reader = (ifd_reader_t *) calloc(1, sizeof(*reader));
