@@ -28,24 +28,6 @@
 
 #include "usb-descriptors.h"
 
-int ifd_sysdep_device_type(const char *name)
-{
-	struct stat stb;
-
-	ifd_debug(1, "BSD: ifd_sysdep_device_type(%s)", name);
-	if (!name || name[0] != '/')
-		return -1;
-
-	if (!strncmp(name, "/dev/ugen", 9)) {
-		ifd_debug(1, "BSD: returning IFD_DEVICE_TYPE_USB");
-		if (stat(name, &stb) < 0)
-			return -1;
-		return IFD_DEVICE_TYPE_USB;
-	}
-
-	return -1;
-}
-
 /*
  * Poll for presence of USB device
  */
@@ -333,6 +315,12 @@ int ifd_sysdep_usb_open(const char *device)
         return open(device, O_RDWR);
 }
 
+int ifd_sysdep_usb_reset(ifd_device_t * dev)
+{
+	/* not implemented so far */
+	return -1;
+}
+
 /*
  * Scan all usb devices to see if there is one we support
  */
@@ -359,7 +347,7 @@ int ifd_scan_usb(void)
 			struct usb_device_info device_info;
 			ifd_devid_t id;
 			const char *driver;
-			char device[256];
+			char typedev[256];
 
 			device_info.udi_addr = address;
 
@@ -390,11 +378,15 @@ int ifd_scan_usb(void)
 
 			if (!(driver = ifd_driver_for_id(&id)))
 				continue;
+#ifdef __OpenBSD__
+			snprintf(typedev, sizeof(typedev),
+				"usb:/dev/%s.00", device_info.udi_devnames[0]);
+#else
+			snprintf(typedev, sizeof(typedev),
+				 "usb:/dev/%s", device_info.udi_devnames[0]);
+#endif	/* __OpenBSD__ */
 
-			snprintf(device, sizeof(device),
-				 "/dev/%s", device_info.udi_devnames[0]);
-
-			ifd_spawn_handler(driver, device, -1);
+			ifd_spawn_handler(driver, typedev, -1);
 		}
 		close(controller_fd);
 	}
