@@ -141,49 +141,8 @@ struct usbdevfs_hub_portinfo {
 #define USBDEVFS_DISCONNECT        _IO('U', 22)
 #define USBDEVFS_CONNECT           _IO('U', 23)
 
-/* other constants from kernel code */
-
-#define TTY_MAJOR            4
-#define PTY_SLAVE_MAJOR              3
-#define UNIX98_PTY_MASTER_MAJOR      128
-#define UNIX98_PTY_SLAVE_MAJOR       (UNIX98_PTY_MASTER_MAJOR+UNIX98_PTY_MAJOR_COUNT)
-#define UNIX98_PTY_MAJOR_COUNT       8
-#define MISC_MAJOR           10
-
 /* end of import from usbdevice_fs.h */
 
-int ifd_sysdep_device_type(const char *name)
-{
-	struct stat stb;
-
-	if (!name || name[0] != '/')
-		return -1;
-
-	if (!strncmp(name, "/proc/bus/usb", 13) ||
-		!strncmp(name, "/dev/bus/usb", 12)) 
-		return IFD_DEVICE_TYPE_USB;
-
-	if (stat(name, &stb) < 0)
-		return -1;
-
-	if (S_ISCHR(stb.st_mode)) {
-		int major = major(stb.st_rdev);
-		int minor = minor(stb.st_rdev);
-
-		if (major == TTY_MAJOR
-		    || major == PTY_SLAVE_MAJOR
-		    || (UNIX98_PTY_SLAVE_MAJOR <= major
-			&& major <
-			UNIX98_PTY_SLAVE_MAJOR + UNIX98_PTY_MAJOR_COUNT))
-			return IFD_DEVICE_TYPE_SERIAL;
-
-		if (major == MISC_MAJOR && minor == 1)
-			return IFD_DEVICE_TYPE_PS2;
-	}
-
-	return -1;
-}
-
 /*
  * Poll for presence of USB device
  */
@@ -263,6 +222,15 @@ int ifd_sysdep_usb_release_interface(ifd_device_t * dev, int interface)
 	return 0;
 }
 
+int ifd_sysdep_usb_reset(ifd_device_t * dev)
+{
+	if (ioctl(dev->fd, USBDEVFS_RESET, NULL) < 0) {
+		ct_error("usb_reset failed: %m");
+		return IFD_ERROR_COMM_ERROR;
+	}
+	return 0;
+}
+
 /*
  * USB bulk transfer
  */
@@ -430,7 +398,7 @@ int ifd_scan_usb(void)
 	for (bus = usb_busses; bus; bus = bus->next) {
 		for (dev = bus->devices; dev; dev = dev->next) {
 			const char *driver;
-			char device[PATH_MAX];
+			char typedev[PATH_MAX];
 			struct stat buf;
 
 			id.val[0] = dev->descriptor.idVendor;
@@ -439,17 +407,19 @@ int ifd_scan_usb(void)
 			if (!(driver = ifd_driver_for_id(&id)))
 				continue;
 
-			snprintf(device, sizeof(device),
+			snprintf(typedev, sizeof(typedev),
 				 "/dev/bus/usb/%s/%s",
 				 bus->dirname, dev->filename);
-			if (stat(device, &buf) == 0) {
-				ifd_spawn_handler(driver, device, -1);
-			} else {
-				snprintf(device, sizeof(device),
-				 	"/proc/bus/usb/%s/%s",
+			if (stat(typedev, &buf) == 0) {
+				snprintf(typedev, sizeof(typedev),
+				 	"usb:/dev/bus/usb/%s/%s",
 				 	bus->dirname, dev->filename);
-			
-				ifd_spawn_handler(driver, device, -1);
+				ifd_spawn_handler(driver, typedev, -1);
+			} else {
+				snprintf(typedev, sizeof(typedev),
+				 	"usb:/proc/bus/usb/%s/%s",
+				 	bus->dirname, dev->filename);
+				ifd_spawn_handler(driver, typedev, -1);
 			}
 		}
 	}
