@@ -13,11 +13,6 @@
 #include <stdio.h>
 #include <openct/driver.h>
 
-int ifd_sysdep_device_type(const char *name)
-{
-	return -1;
-}
-
 /*
  * USB handling
  */
@@ -103,6 +98,11 @@ int ifd_sysdep_usb_open(const char *device)
 	return -1;
 }
 
+int ifd_sysdep_usb_reset(ifd_device_t * dev)
+{
+	return -1;
+}
+
 /*
  * Scan all usb devices to see if there is one we support
  */
