@@ -221,36 +221,6 @@ prepare_usb_control_req(usb_request_t * req, uint8_t bmRequestType,
 #endif				/* _BIG_ENDIAN */
 }
 
-int ifd_sysdep_device_type(const char *name)
-{
-	char *cwd;
-
-	if ((cwd = getcwd(NULL, PATH_MAX)) == NULL) {
-		return -1;
-	}
-	/*
-	 * A USB device that is supported through the UGEN driver
-	 * is typically indicated by its control endpoint.
-	 * Eg /dev/usb/<vendor>.<product>/<instance>/cntrl0
-	 */
-	ifd_debug(6, "ifd_sysdep_device_type: cwd=\"%s\" name=\"%s\"", cwd,
-		  name);
-
-	if (!name || name[0] != '/') {
-		ifd_debug(6,
-			  "ifd_sysdep_device_type: device name does not start with \"/\"");
-		return -1;
-	}
-
-	if (strncmp(name, "/dev/usb/", 9) == 0) {
-		ifd_debug(6, "ifd_sysdep_device_type: detected USB device");
-		return IFD_DEVICE_TYPE_USB;
-	}
-
-	ifd_debug(6, "ifd_sysdep_device_type: No USB device detected");
-	return -1;
-}
-
 /*
  * Poll for presence of USB device
  */
@@ -534,6 +504,12 @@ int ifd_sysdep_usb_open(const char *device)
         return open(device, O_RDWR);
 }
 
+int ifd_sysdep_usb_reset(ifd_device_t * dev)
+{
+	/* not implemented so far */
+        return -1;
+}
+
 /*
  * Scan the /dev/usb directory to see if there is any control pipe matching:
  *
@@ -590,6 +566,7 @@ int ifd_scan_usb(void)
 		do {
 			int device = -1;
 			char device_instance_cntrl0_name[256];
+			char typedev[256];
 			struct stat dummy;
 
 			errno = 0;
@@ -610,9 +587,9 @@ int ifd_scan_usb(void)
 				ifd_debug(1,
 					  "ifd_scan_usb: \t\tfound device instance %s\n",
 					  device_instance_cntrl0_name);
-				ifd_spawn_handler(driver,
-						  device_instance_cntrl0_name,
-						  -1);
+				snprintf(typedev,sizeof(typedev),
+					"usb:%s", device_instance_cntrl0_name);
+				ifd_spawn_handler(driver, typedev, -1);
 			}
 		} while (device_instance != NULL);
 		if (errno != 0)
