@@ -45,7 +45,7 @@ typedef struct ct_handle	ct_handle;
 typedef unsigned int	ct_lock_handle;
 enum {
 	IFD_LOCK_SHARED,
-	IFD_LOCK_EXCLUSIVE,
+	IFD_LOCK_EXCLUSIVE
 };
 
 /*
@@ -53,7 +53,7 @@ enum {
  */
 enum {
 	IFD_PIN_ENCODING_BCD,
-	IFD_PIN_ENCODING_ASCII,
+	IFD_PIN_ENCODING_ASCII
 };
 
 extern int		ct_status(const ct_info_t **);
@@ -92,7 +92,7 @@ extern int		ct_card_write_memory(ct_handle *, unsigned int slot,
 				const void *send_buf, size_t send_len);
 
 extern int		ct_status_clear(unsigned int);
-extern ct_info_t *	ct_status_alloc_slot(unsigned int *);
+extern ct_info_t *	ct_status_alloc_slot(int *);
 extern int		ct_status_update(ct_info_t *);
 
 #ifdef __cplusplus
